*****************************************
Photometric equalization for AstroDrizzle
*****************************************

.. moduleauthor:: Mihai Cara <help@stsci.edu>

.. automodule:: drizzlepac.photeq

.. autofunction:: photeq
.. autofunction:: help
